@@ -41,7 +41,7 @@ def totif(images, path, prefix="image", overwrite=False, credentials=None):
         raise ValueError("Only 2D or 3D images can be exported to tif, "
                          "images are %d-dimensional." % len(value_shape))
 
-    from scipy.misc import imsave
+    from tifffile import imsave
     from io import BytesIO
     from thunder.writers import get_parallel_writer
 
@@ -49,7 +49,7 @@ def totif(images, path, prefix="image", overwrite=False, credentials=None):
         key, img = kv
         fname = prefix+"-"+"%05d.tif" % int(key)
         bytebuf = BytesIO()
-        imsave(bytebuf, img, format='TIFF')
+        imsave(bytebuf, img)
         return fname, bytebuf.getvalue()
 
     writer = get_parallel_writer(path)(path, overwrite=overwrite, credentials=credentials)
